@@ -127,6 +127,7 @@ class DeliveryInstance_:
             else:
                 method_ = method
 
+            # try:
             if self._bci_mode == 'dashboard':
                 try:
                     cls.both(method_)(self, *args, **kwargs)
@@ -135,8 +136,15 @@ class DeliveryInstance_:
             else:
                 try:
                     cls.rboth(method_)(self, *args, **kwargs)
-                except:
+                except TypeError:
                     cls.rboth(method_)(*args, **kwargs)
+            # except Exception as e:
+                # logging.warning(e)
+                # logging.warning('#' * 15)
+                # logging.warning(f'Method: {method_}')
+                # logging.warning(f'args: {args}')
+                # logging.warning(f'kwargs: {kwargs}')
+                # logging.warning('#' * 15)
 
         wrap.no_decorator = method
         return wrap
@@ -173,20 +181,14 @@ class BCIWebSocket(WebSocket):
     # ----------------------------------------------------------------------
     def on_close(self, evt):
         """"""
-        print('on_close', self.ip_)
-        # timer.set_timeout(lambda: self.__init__(self.ip_), 1000)
-        # getattr(self.main, 'stop', lambda: None)()
-        window.location.replace(self.ip_.replace('/ws', '').replace(
-            'ws', 'http'))
+        window.location.replace(self.ip_.replace(
+            '/ws', '').replace('ws', 'http'))
 
     # ----------------------------------------------------------------------
     def on_error(self, evt):
         """"""
-        print('on_error', self.ip_)
-        # timer.set_timeout(lambda: self.__init__(self.ip_), 1000)
-        # getattr(self.main, 'stop', lambda: None)()
-        window.location.replace(self.ip_.replace('/ws', '').replace(
-            'ws', 'http'))
+        window.location.replace(self.ip_.replace(
+            '/ws', '').replace('ws', 'http'))
 
 
 ########################################################################
@@ -198,10 +200,12 @@ class Pipeline:
         """"""
         explicit_pipeline = []
         for method, var in pipeline:
+
             if isinstance(var, str):
                 var = w.get_value(var)
             if isinstance(var, [list, tuple, set]):
                 var = random.randint(*var)
+
             if isinstance(method, str):
                 explicit_pipeline.append([getattr(self, method), var])
             else:
@@ -210,17 +214,28 @@ class Pipeline:
         return explicit_pipeline
 
     # ----------------------------------------------------------------------
-    def run_pipeline(self, pipeline, trials, callback=None):
+    def run_pipeline(self, pipeline, trials, callback=None, show_progressbar=True):
         """"""
-        self.show_progressbar(len(trials) * len(pipeline))
+        # self._callback = callback
+        if show_progressbar:
+            self.show_progressbar(len(trials) * len(pipeline))
+        # self.set_autoprogress(show_progressbar)
 
         if self.DEBUG:
+            self.set_autoprogress.no_decorator(self, show_progressbar)
             self._prepare.no_decorator(self, callback)
             self._run_pipeline.no_decorator(self, pipeline, trials)
         else:
+            self.set_autoprogress(show_progressbar)
             self._prepare(callback)
             self._run_pipeline(pipeline, trials)
 
+    # ----------------------------------------------------------------------
+    @DeliveryInstance.both
+    def set_autoprogress(self, value):
+        """"""
+        self._autoprogress = value
+
     # ----------------------------------------------------------------------
     @DeliveryInstance.both
     def _prepare(self, callback):
@@ -302,7 +317,8 @@ class Pipeline:
     # ----------------------------------------------------------------------
     def on_callback(self):
         """"""
-        DeliveryInstance.event(self.set_progress)(self, 0)
+        if self._autoprogress:
+            DeliveryInstance.event(self.set_progress)(self, 0)
         if getattr(self, '_callback', None):
             DeliveryInstance.event(self._callback)(self)
 
@@ -364,6 +380,16 @@ class StimuliAPI(Pipeline):
     def start_record(self):
         """"""
         self.send_annotation('start_record')
+        timer.set_timeout(self._send_custom_annotations, 15000)
+
+    # ----------------------------------------------------------------------
+    def _send_custom_annotations(self):
+        """"""
+        prefix = 'annotation-'
+        data = w.get_prefix(prefix)
+        for k in data:
+            description = f'{k.replace(prefix, "").capitalize()}: {data[k]}'
+            self.send_annotation(description)
 
     # ----------------------------------------------------------------------
     @DeliveryInstance.event
@@ -374,6 +400,7 @@ class StimuliAPI(Pipeline):
     # ----------------------------------------------------------------------
     def send_annotation(self, description, duration=0, force=False):
         """"""
+        logging.warning(f'Annotation: {description}')
         if self.mode == 'stimuli' or force or self.DEBUG:
             self.ws.send({
                 'action': 'annotation',
@@ -516,7 +543,7 @@ class StimuliAPI(Pipeline):
                 'width': f'{size}px',
                 'height': f'{size}px',
                 'background-color': color_off,
-                'position': 'absolute',
+                'position': 'fixed',
                 'top': top,
                 'left': left,
                 'border-radius': '100%',
@@ -537,7 +564,7 @@ class StimuliAPI(Pipeline):
                 'width': f'{size}px',
                 'height': f'{size}px',
                 'background-color': color_off,
-                'position': 'absolute',
+                'position': 'fixed',
                 'top': top,
                 'left': left,
                 'z-index': 999,
