@@ -6,12 +6,13 @@ BCIEditor
 """
 
 import os
+import ast
 import json
 from typing import Literal, TypeVar
 
-from PySide2.QtWidgets import QTextEdit, QCompleter
-from PySide2.QtGui import QTextOption
-from PySide2.QtCore import Qt
+from PySide6.QtWidgets import QTextEdit, QCompleter
+from PySide6.QtGui import QTextOption
+from PySide6.QtCore import Qt
 
 from .highlighters import PythonHighlighter, CSSHighlighter
 
@@ -38,34 +39,45 @@ class BCIEditor(QTextEdit):
 
         self.set_options()
         self.linenumber = linenumber
+        self.temporal_vars = []
 
         if 'light' in os.environ.get('QTMATERIAL_THEME'):
             font_color = 'black'
         else:
             font_color = 'white'
 
-        if json.loads(os.getenv('BCISTREAM_RASPAD')):
-            font_size = 11
-        else:
-            font_size = 15
+        f = self.fontMetrics()
+        font_size = f.height()
 
         self.setStyleSheet(f"""
         QTextEdit {{
         background-color: {os.environ.get('QTMATERIAL_SECONDARYDARKCOLOR')};
         color: {font_color};
-        height: 18px;
         font-weight: normal;
         font-family: 'DejaVu Sans Mono';
         font-size: {font_size}px;
         line-height: {font_size}px;
         border: 1px solid {os.environ.get('QTMATERIAL_SECONDARYDARKCOLOR')};
         border-radius: 4px;
-        height: 18px;
         padding: 0px;
         padding-top: 8px;
         }}
         """)
 
+        linenumber.setStyleSheet(f"""
+        QTextEdit.linenumber {{
+        background-color: {os.environ.get('QTMATERIAL_SECONDARYDARKCOLOR')};
+        color: {os.environ.get('QTMATERIAL_SECONDARYTEXTCOLOR')};
+        font-weight: normal;
+        font-family: 'DejaVu Sans Mono';
+        font-size: {font_size}px;
+        line-height: {font_size}px;
+        border: 0px solid {os.environ.get('QTMATERIAL_SECONDARYLIGHTCOLOR')};
+        border-right: 10px solid {os.environ.get('QTMATERIAL_SECONDARYLIGHTCOLOR')};
+        border-radius: 0px;
+        }}
+        """)
+
         if extension == '.py':
             PythonHighlighter(self.document())
         elif extension == '.css':
@@ -92,15 +104,10 @@ class BCIEditor(QTextEdit):
         lines = len(self.toPlainText().split('\n'))
         lines_ln = len(self.linenumber.toPlainText().split('\n'))
 
-        if json.loads(os.getenv('BCISTREAM_RASPAD')):
-            font_size = 11
-        else:
-            font_size = 15
-
         if lines != lines_ln:
             content = [f'{l}' for l in range(1, lines + 1)]
             self.linenumber.setHtml(
-                f'<p style="text-align: right; line-height: {font_size}px; font-size: {font_size}px">{"<br>".join(content)}</p>')
+                f'<p style="text-align: right">{"<br>".join(content)}</p>')
         self.linenumber.verticalScrollBar().setValue(self.verticalScrollBar().value())
 
     # ----------------------------------------------------------------------
@@ -393,8 +400,8 @@ class BCIEditor(QTextEdit):
         tc.insertText(extra)
 
         if text_position > 0:
-            tc.setPosition(pos + text_position
-                           + (4 * extra[:text_position].count('\n')))
+            tc.setPosition(pos + text_position +
+                           (4 * extra[:text_position].count('\n')))
 
         self.setTextCursor(tc)
 
@@ -442,6 +449,7 @@ class BCIEditor(QTextEdit):
     # ----------------------------------------------------------------------
     def show_completer(self, completion_prefix: str) -> None:
         """Show better options for current text."""
+        # self.completer.set_temporal(self.get_variables())
         self.completer.setCompletionPrefix(completion_prefix)
         popup = self.completer.popup()
         popup.setCurrentIndex(self.completer.completionModel().index(0, 0))
@@ -451,3 +459,14 @@ class BCIEditor(QTextEdit):
         cr.setHeight(30)
 
         self.completer.complete(cr)
+
+    # # ----------------------------------------------------------------------
+    # def get_variables(self):
+        # """"""
+        # try:
+            # root = ast.parse(self.toPlainText())
+            # self.temporal_vars = sorted({node.id for node in ast.walk(
+                # root) if isinstance(node, ast.Name)})
+        # except:
+            # pass
+        # return self.temporal_vars
